@@ -1,4 +1,4 @@
-/* $Id: thunar-tree-view.c 23151 2006-09-13 23:36:10Z benny $ */
+/* $Id: thunar-tree-view.c 26457 2007-12-11 19:30:45Z benny $ */
 /*-
  * Copyright (c) 2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -1041,13 +1041,12 @@ thunar_tree_view_context_menu (ThunarTreeView *view,
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
       gtk_widget_show (item);
 
-      /* check if the volume is a disc */
-      if (thunar_vfs_volume_is_disc (volume))
+      /* check if the volume is ejectable */
+      if (thunar_vfs_volume_is_ejectable (volume))
         {
           /* append the "Eject Volume" menu action */
           item = gtk_image_menu_item_new_with_mnemonic (_("E_ject Volume"));
           g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_tree_view_action_eject), view);
-          gtk_widget_set_sensitive (item, thunar_vfs_volume_is_ejectable (volume));
           gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
           gtk_widget_show (item);
         }
